import sqlalchemy as rdb

from zope import component

from ore.contentmirror.transform import BaseFieldTransformer
from ore.contentmirror.interfaces import ISchemaTransformer

from mirror.pfg import interfaces

class TALESStringTransform( BaseFieldTransformer ):
    component.adapts( interfaces.ITALESStringField, ISchemaTransformer )
    column_type = rdb.Text
    column_args = ()




import unittest
from zope import component, interface
from zope.testing import doctest

from ore.contentmirror.testing import setUp as _setUp
from ore.contentmirror.testing import tearDown, doctest_ns, MockField

from mirror.pfg import transform, interfaces

class TALESString(MockField):
    interface.implements(interfaces.ITALESStringField)

def setUp(test):
    _setUp(test)
    component.provideAdapter(transform.TALESStringTransform)

def test_suite():
    ns = dict(doctest_ns)
    ns['TALESString'] = TALESString

    return unittest.TestSuite(
        doctest.DocFileSuite(
        'readme.txt',
        setUp=setUp, tearDown=tearDown,
        optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
        globs=ns
        ),)



import os
from setuptools import setup, find_packages

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

setup(
    name="mirror.pfg",
    version=read('version.txt').strip(),
    url="http://contentmirror.googlecode.com",
    install_requires=['setuptools',
                      'zope.testing',
                      'ore.contentmirror'],
    packages=find_packages(exclude=["*.tests"]),
    namespace_packages=['mirror'],
    package_data = {
      '': ['*.txt', '*.zcml'],
    },
    zip_safe=False,
    author='Tim Miho',
    description="Extension for Content Mirror to Support Plone Form Gen",
    license='GPL',
    keywords="plone",
    )
